@@ -12,10 +12,11 @@
 #endif /* HAVE_CONFIG_H */
 
 #ifdef AUTH_LDAP
-static const char rcsid[] = "$Id: auth_ldap.c,v 1.5 2002/02/25 18:16:05 chris Exp $";
+static const char rcsid[] = "$Id: auth_ldap.c,v 1.15 2003/07/18 08:30:27 chris Exp $";
 
 #include <sys/types.h> /* BSD needs this here, apparently. */
 
+#include <lber.h>
 #include <ldap.h>
 #include <pwd.h>
 #include <stdio.h>
@@ -221,34 +222,70 @@ int auth_ldap_init(void) {
 
     r = 1;
 
-    auth_ldap_connect();
-
 fail:
     return r;
 }
 
 extern int verbose; /* in main.c */
 
+/* ldap_strerror:
+ * Return the current error string from the LDAP library. */
 static char *ldap_strerror(void) {
     int ld_errno;
     ldap_get_option(ldapinfo.ldap, LDAP_OPT_ERROR_NUMBER, &ld_errno);
     return ldap_err2string(ld_errno);
 }
 
+/* try_ldap_connect_bind:
+ * Try to connect to the LDAP server and bind. */
+static int try_ldap_connect_bind(const char *who, const char *passwd) {
+    int ret = LDAP_OTHER, i;    /* XXX */
+    for (i = 0; i < 3; ++i) {
+        if (ldapinfo.ldap || auth_ldap_connect()) {
+            ret = ldap_simple_bind_s(ldapinfo.ldap, who, passwd);
+            if (ret == LDAP_SUCCESS)
+                return LDAP_SUCCESS;
+            else {
+                log_print(LOG_ERR, "try_ldap_connect_bind: ldap_simple_bind_s: %s", ldap_err2string(ret));
+                ldap_unbind(ldapinfo.ldap);
+                ldapinfo.ldap = NULL;
+            }
+        } else
+            ldapinfo.ldap = NULL;
+    }
+
+    /* OK, didn't succeed. */
+    return ret;
+}
+
+/* try_ldap_bind:
+ * Try a bind against the LDAP server. */
+static int try_ldap_bind(LDAP *ld, const char *who, const char *passwd) {
+    int ret, i;
+    for (i = 0; i < 3; ++i) {
+        ret = ldap_simple_bind_s(ld, who, passwd);
+        if (ret == LDAP_SUCCESS)
+            return LDAP_SUCCESS;
+    }
+    return ret;
+}
+
 /* auth_ldap_new_user_pass:
  * Attempt to authenticate user against the directory, using a two-step
  * search/bind process. */
-authcontext auth_ldap_new_user_pass(const char *username, const char *local_part, const char *domain, const char *pass, const char *host /* unused */) {
+authcontext auth_ldap_new_user_pass(const char *username, const char *local_part, const char *domain, const char *pass, const char *clienthost /* unused */, const char *serverhost /* unused */) {
     authcontext a = NULL;
-    char *filter = NULL;
+    char *filter = NULL, *who;
     LDAPMessage *ldapres = NULL, *user_attr = NULL;
     char *user_dn = NULL;
-    int nentries, ret, i;
+    int nentries, ret;
 
-    /* Give up if there is no connection available. */
-    if (!ldapinfo.ldap) {
-        log_print(LOG_ERR, _("auth_ldap_new_user_pass: no connection to LDAP server"));
-        return NULL;
+    who = username_string(username, local_part, domain);
+
+    /* Connect to the server. */
+    if (try_ldap_connect_bind(ldapinfo.searchdn, ldapinfo.password) != LDAP_SUCCESS) {
+        log_print(LOG_ERR, _("auth_ldap_new_user_pass: unable to connect and bind to LDAP server"));
+        goto fail;
     }
 
     /* Obtain search filter. */
@@ -258,42 +295,25 @@ authcontext auth_ldap_new_user_pass(const char *username, const char *local_part
     if (verbose)
         log_print(LOG_DEBUG, _("auth_ldap_new_user_pass: LDAP search filter: %s"), filter);
 
-    /* Try to bind to the LDAP server, reconnecting if it's gone away. */
-    for (i = 0; i < 3; ++i) {
-        if (ldapinfo.ldap && (ret = ldap_simple_bind_s(ldapinfo.ldap, ldapinfo.searchdn, ldapinfo.password)) != LDAP_SUCCESS) {
-            log_print(LOG_ERR, "auth_ldap_new_user_pass: ldap_simple_bind_s: %s", ldap_err2string(ret));
-            ldap_unbind(ldapinfo.ldap);  /* not much we can do if this fails.... */
-            ldapinfo.ldap = NULL;
-        } else break;
-        if (!ldapinfo.ldap)
-            auth_ldap_connect();
-    }
-
-    if (!ldapinfo.ldap) {
-        log_print(LOG_ERR, _("auth_ldap_new_user_pass: unable to connect to LDAP server"));
-        goto fail;
-    }
-
     /* Look for DN of user in the directory. */
     if ((ret = ldap_search_s(ldapinfo.ldap, ldapinfo.dn, LDAP_SCOPE_SUBTREE, filter, NULL, 0, &ldapres)) != LDAP_SUCCESS) {
         log_print(LOG_ERR, "auth_ldap_new_user_pass: ldap_search_s: %s", ldap_err2string(ret));
         goto fail;
     }
- 
+
     /* There must be only one result. */
     switch (nentries = ldap_count_entries(ldapinfo.ldap, ldapres)) {
         case 1:
             break;
 
         default:
-            log_print(LOG_ERR, _("auth_ldap_new_user_pass: search returned %d entries"), nentries);
+            log_print(LOG_ERR, _("auth_ldap_new_user_pass: search returned %d entries, should be 0 or 1"), nentries);
             /* fall through */
 
         case 0:
             goto fail;
     }
 
-    /* Obtain attributes of search result. */
     if (!(user_attr = ldap_first_entry(ldapinfo.ldap, ldapres))) {
         log_print(LOG_ERR, "auth_ldap_new_user_pass: ldap_first_entry: %s", ldap_strerror());
         goto fail;
@@ -306,12 +326,12 @@ authcontext auth_ldap_new_user_pass(const char *username, const char *local_part
     }
 
     /* Now attempt authentication by binding with the user's credentials. */
-    if ((ret = ldap_simple_bind_s(ldapinfo.ldap, user_dn, pass)) != LDAP_SUCCESS) {
+    if ((ret = try_ldap_bind(ldapinfo.ldap, user_dn, pass)) != LDAP_SUCCESS) {
         /* Bind failed; user has failed to log in. */
         if (ret == LDAP_INVALID_CREDENTIALS)
-            log_print(LOG_ERR, _("auth_ldap_new_user_pass: failed login for %s%s%s"), local_part, domain ? "@" : "", domain ? domain : "");
+            log_print(LOG_ERR, _("auth_ldap_new_user_pass: failed login for %s"), who);
         else
-            log_print(LOG_ERR, "auth_ldap_new_user_pass: ldap_simple_bind_s: %s", ldap_err2string(ret));
+            log_print(LOG_ERR, "auth_ldap_new_user_pass: try_ldap_bind: %s", ldap_err2string(ret));
         goto fail;
     } else {
         /* Bind OK; accumulate information about this user and generate an
@@ -341,16 +361,15 @@ authcontext auth_ldap_new_user_pass(const char *username, const char *local_part
                 group = xstrdup(*vals);
 
             ldap_value_free(vals);
+            ldap_memfree(attr);
         }
 
-        /* Do NOT need to free the ber, apparently-- ldap_next_attribute frees
-         * it when it returns NULL. */
-        if (attr) ldap_memfree(attr);
+        ber_free(ber, 0);
 
         /* Check that we've retrieved all the attributes we need. */
-#define GOT_ATTR(a)     if (ldapinfo.attr.##a && !a) { \
-                            log_print(LOG_ERR, _("auth_ldap_new_user_pass: did not find required attribute `%s' for %s%s%s"), \
-                                      ldapinfo.attr.##a, local_part, domain ? "@" : "", domain ? domain : ""); \
+#define GOT_ATTR(a)     if (ldapinfo.attr.a && !a) { \
+                            log_print(LOG_ERR, _("auth_ldap_new_user_pass: did not find required attribute `%s' for %s"), \
+                                      ldapinfo.attr.a, who); \
                             goto fail; \
                         }
         GOT_ATTR(mailbox);
@@ -363,9 +382,9 @@ authcontext auth_ldap_new_user_pass(const char *username, const char *local_part
         uid = ldapinfo.uid;
         gid = ldapinfo.gid;
         if (user && !parse_uid(user, &uid))
-            log_print(LOG_ERR, _("auth_ldap_new_user_pass: unix user `%s' for %s%s%s does not make sense"), user, local_part, domain ? "@" : "", domain ? domain : "");
+            log_print(LOG_ERR, _("auth_ldap_new_user_pass: unix user `%s' for %s does not make sense"), user, who);
         else if (group && !parse_gid(group, &gid))
-            log_print(LOG_ERR, _("auth_ldap_new_user_pass: unix group `%s' for %s%s%s does not make sense"), group, local_part, domain ? "@" : "", domain ? domain : "");
+            log_print(LOG_ERR, _("auth_ldap_new_user_pass: unix group `%s' for %s does not make sense"), group, who);
         else {
             struct passwd *pw;
             char *home = NULL;
@@ -393,19 +412,26 @@ authcontext auth_ldap_new_user_pass(const char *username, const char *local_part
     }
 
 fail:
+    /* Ugly: force the LDAP library to free user_addr. */
+    if (user_attr) while (ldap_next_entry(ldapinfo.ldap, ldapres));
+    
     if (ldapres) ldap_msgfree(ldapres);
-/*    if (user_attr) ldap_msgfree(user_attr);*/
-    if (user_dn) free(user_dn);
+    if (user_dn) ldap_memfree(user_dn);
 
     xfree(filter);
 
+/*    auth_ldap_close();*/
+
     return a;
 }
 
 /* auth_ldap_close:
  * Close the ldap connection. */
 void auth_ldap_close() {
-  if (ldapinfo.ldap) ldap_unbind(ldapinfo.ldap);
+    if (ldapinfo.ldap) {
+        ldap_unbind(ldapinfo.ldap);
+        ldapinfo.ldap = NULL;
+    }
 }
 
 /* auth_ldap_postfork:
@@ -452,7 +478,7 @@ static char *substitute_filter_params(const char *template, const char *user, co
     if (domain)
         d = xstrdup(ldap_escape(domain));
 
-    filter = substitute_variables(template, &err, 3, "user", user, "local_part", l, "domain", d);
+    filter = substitute_variables(template, &err, 3, "user", u, "local_part", l, "domain", d);
 
     if (!filter && err.code != sv_nullvalue)
         log_print(LOG_ERR, _("substitute_filter_params: %s near `%.16s'"), err.msg, template + err.offset);
