@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2001 Chris Lightfoot. All rights reserved.
  *
- * $Id: auth_mysql.h,v 1.5 2001/04/23 23:45:40 chris Exp $
+ * $Id: auth_mysql.h,v 1.11 2002/06/25 20:28:00 chris Exp $
  *
  */
 
@@ -30,12 +30,14 @@
 /* Config directive: auth-mysql-mail-group */
 #undef AUTH_MYSQL_MAIL_GID
 
-int  auth_mysql_init();
+int  auth_mysql_init(void);
 
 /* These use SELECT statements defined in auth_mysql.c */
-authcontext auth_mysql_new_apop(const char *name, const char *timestamp, const unsigned char *digest);
-authcontext auth_mysql_new_user_pass(const char *user, const char *pass);
-void auth_mysql_close();
+authcontext auth_mysql_new_apop(const char *name, const char *local_part, const char *domain, const char *timestamp, const unsigned char *digest, const char *clienthost, const char *serverhost);
+authcontext auth_mysql_new_user_pass(const char *user, const char *local_part, const char *domain, const char *pass, const char *clienthost, const char *serverhost);
+void auth_mysql_onlogin(const authcontext A, const char *clienthost, const char *serverhost);
+void auth_mysql_postfork(void);
+void auth_mysql_close(void);
 
 #endif /* AUTH_MYSQL */
 
