@@ -6,7 +6,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: authswitch.c,v 1.33 2002/06/25 20:28:00 chris Exp $";
+static const char rcsid[] = "$Id: authswitch.c,v 1.41 2003/07/14 23:31:20 chris Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "configuration.h"
@@ -28,6 +28,10 @@ static const char rcsid[] = "$Id: authswitch.c,v 1.33 2002/06/25 20:28:00 chris
 #include "auth_mysql.h"
 #endif /* AUTH_MYSQL */
 
+#ifdef AUTH_PGSQL
+#include "auth_pgsql.h"
+#endif /* AUTH_PGSQL */
+
 #ifdef AUTH_OTHER
 #include "auth_other.h"
 #endif /* AUTH_OTHER */
@@ -48,6 +52,10 @@ static const char rcsid[] = "$Id: authswitch.c,v 1.33 2002/06/25 20:28:00 chris
 #include "auth_passwd.h"
 #endif /* AUTH_PASSWD */
 
+#ifdef USE_WHOSON
+#include <whoson.h>
+#endif
+
 #include "authswitch.h"
 #include "config.h"
 #include "stringmap.h"
@@ -80,6 +88,13 @@ struct authdrv auth_drivers[] = {
             _X("Uses a MySQL database")},
 #endif /* AUTH_MYSQL */
 
+#ifdef AUTH_PGSQL
+        /* Postgres. */
+        {auth_pgsql_init, auth_pgsql_new_apop, auth_pgsql_new_user_pass, auth_pgsql_onlogin, auth_pgsql_postfork, auth_pgsql_close,
+            "pgsql",
+            _X("Uses a Postgres database")},
+#endif /* AUTH_PGSQL */
+
 #ifdef AUTH_LDAP
         /* Authenticate against a directory. */
         {auth_ldap_init, NULL, auth_ldap_new_user_pass, NULL, auth_ldap_postfork, auth_ldap_close,
@@ -103,7 +118,7 @@ struct authdrv auth_drivers[] = {
 
 #ifdef AUTH_FLATFILE
         /* Authenticate against /etc/passwd-style flat files. */
-        {auth_flatfile_init, NULL, auth_flatfile_new_user_pass, NULL, NULL, NULL,
+        {auth_flatfile_init, auth_flatfile_new_apop, auth_flatfile_new_user_pass, NULL, NULL, NULL,
             "flatfile",
             _X("Uses /etc/passwd-style flat files")},
 #endif /* AUTH_FLATFILE */
@@ -155,6 +170,9 @@ extern stringmap config;
 #ifdef USE_DRAC
 static char *drac_server;
 #endif
+#ifdef USE_WHOSON
+static int whoson_enable;
+#endif
     
 int authswitch_init(void) {
     const struct authdrv *aa;
@@ -184,6 +202,11 @@ int authswitch_init(void) {
         log_print(LOG_INFO, _("will notify DRAC server `%s' of logins"), drac_server);
 #endif
 
+#ifdef USE_WHOSON
+    if ((whoson_enable = config_get_bool("whoson-enable")))
+        log_print(LOG_INFO, _("will notify logins by WHOSON"));
+#endif
+    
     return ret;
 }
 
@@ -244,6 +267,13 @@ authcontext authcontext_new_user_pass(const char *user, const char *local_part,
     char *x = NULL;
     const char *l = NULL, *d = NULL;
 
+    /* This is here mainly for users who forgot to switch off LDAP anonymous
+     * authentication.... */
+    if (*pass == 0 && !config_get_bool("permit-empty-password")) {
+        log_print(LOG_WARNING, _("authcontext_new_user_pass: rejecting login attempt by `%s' with empty password"), user);
+        return NULL;
+    }
+    
     l = local_part;
     d = domain;
     
@@ -288,15 +318,25 @@ authcontext authcontext_new_user_pass(const char *user, const char *local_part,
 void authswitch_onlogin(const authcontext A, const char *clienthost, const char *serverhost) {
     const struct authdrv *aa;
     int *aar;
+#ifdef USE_DRAC
+    /* in -ldrac */
+    int dracauth(char *server, unsigned long userip, char **errmsg);
+#endif
+
+#ifdef USE_WHOSON
+    char buf[128] = {0};
+    /* Notify whoson server the user has logged in correctly */
+    if (wso_login(clienthost, A->user, buf, sizeof(buf)) == -1)
+        log_print(LOG_ERR, "authswitch_onlogin: wso_login: %s", buf);
+#endif /* USE_WHOSON */
     
 #ifdef USE_DRAC
     /* Optionally, notify a DRAC -- dynamic relay authentication control -- 
      * server of the login. This uses some wacky RPC thing contained in
      * -ldrac. */
-    int dracauth(char *server, unsigned long userip, char **errmsg);
     if (drac_server) {
         char *errmsg;
-        if (dracauth(drac_server, inet_addr(host), &errmsg))
+        if (dracauth(drac_server, inet_addr(clienthost), &errmsg))
             log_print(LOG_ERR, "authswitch_onlogin: dracauth: %s", errmsg);
     }
 #endif /* USE_DRAC */
@@ -318,9 +358,7 @@ void authswitch_postfork() {
 }
 
 /* authswitch_close:
- * Closes down each authentication driver. Note that it doesn't check whether
- * the driver started successfully, so even drivers which didn't start will
- * get called. So sue me. */
+ * Closes down any authentication drivers which have been started. */
 void authswitch_close() {
     const struct authdrv *aa;
     int *aar;
@@ -335,7 +373,8 @@ void authswitch_close() {
  * Fill in a new authentication context structure with the given information. */
 authcontext authcontext_new(const uid_t uid, const gid_t gid, const char *mboxdrv, const char *mailbox, const char *home) {
     authcontext a;
-    a = xcalloc(1, sizeof *a);
+
+    alloc_struct(_authcontext, a);
 
     a->uid = uid;
     a->gid = gid;
@@ -363,11 +402,6 @@ void authcontext_delete(authcontext a) {
 
     xfree(a->mboxdrv);
     xfree(a->mailbox);
-
-    /* Only log if this is the end of the session, not the parent freeing its
-     * copy of the data. (This is a hack, and I am ashamed.) */
-    if (post_fork) log_print(LOG_INFO, _("authcontext_delete: finished session for `%s' with %s"), a->user, a->auth);
-
     xfree(a->auth);
     xfree(a->user);
     xfree(a->local_part);
