@@ -9,7 +9,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: cfgdirectives.c,v 1.16 2002/06/08 19:41:38 chris Exp $";
+static const char rcsid[] = "$Id: cfgdirectives.c,v 1.23 2003/08/01 12:11:38 chris Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "configuration.h"
@@ -30,6 +30,32 @@ char *cfgdirectives[] = {
     "apop-only",
     "mailbox",
     "no-detach",
+    "permit-empty-passwords",
+    "onlogin-child-wait",
+ 
+#if defined(MBOX_BSD) && defined(MBOX_BSD_SAVE_INDICES)
+    "mailspool-index",
+#endif
+    
+#ifdef USE_TCP_WRAPPERS
+    "tcp-wrappers-name",
+#endif
+
+#ifdef USE_DRAC
+    "drac-server",
+#endif
+
+#ifdef USE_WHOSON
+    "whoson-enable",
+#endif
+    
+#ifdef MBOX_MAILDIR
+    "maildir-exclusive-lock",
+#endif
+
+#ifdef USE_TLS
+    "tls-bug-workarounds",
+#endif
 
 #ifdef AUTH_PAM
     /* auth-pam options */
@@ -59,6 +85,19 @@ char *cfgdirectives[] = {
     "auth-mysql-onlogin-query",
 #endif /* AUTH_MYSQL */
 
+#ifdef AUTH_PGSQL
+    /* auth-pgsql options */
+    "auth-pgsql-enable",
+    "auth-pgsql-username",
+    "auth-pgsql-password",
+    "auth-pgsql-database",
+    "auth-pgsql-hostname",
+    "auth-pgsql-mail-group",
+    "auth-pgsql-pass-query",
+    "auth-pgsql-apop-query",
+    "auth-pgsql-onlogin-query",
+#endif /* AUTH_PGSQL */
+
 #ifdef AUTH_LDAP
     "auth-ldap-enable",
     "auth-ldap-url",
@@ -99,19 +138,7 @@ char *cfgdirectives[] = {
     "auth-flatfile-mail-group",
     "auth-flatfile-passwd-file",
 #endif /* AUTH_FLATFILE */
- 
-#if defined(MBOX_BSD) && defined(MBOX_BSD_SAVE_INDICES)
-    "mailspool-index",
-#endif
-    
-#ifdef USE_TCP_WRAPPERS
-    "tcp-wrappers-name",
-#endif
 
-#ifdef USE_DRAC
-    "drac-server",
-#endif
-    
     /* final entry must be NULL */
     NULL};
 
